import { S3EventRecord } from 'aws-lambda';
import { LambdaConfig } from './lambda-config';
/**
 * Get Lambda config.
 */
export declare class NshmpHazLambdaConfig {
    private lambdaConfig;
    private ssm;
    private s3;
    private sns;
    private iam;
    /**
     * Default options for trigger file.
     * Slices at:
     *    - 4.04E-4 (2% in 50 years)
     *    - 1.03E-3 (5% in 50 years)
     *    - 2.10E-3 (10% in 50 years)
     */
    private defaultOptions;
    constructor(jobId: string);
    /**
     * Return the Lambda config:
     *  - LambdaTriggerConfig
     *  - Raw YAML trigger file contents
     *  - Job ID
     *  - YAML trigger file name
     *  - NshmpLambdaConfig:
     *      - site file contents
     *      - config file contents
     *      - NSHM
     *      - AWS SNS topic
     *  - Ec2LambdaConfig:
     *      - ec2 image ID
     *      - ec2 instance profile
     *      - ec2 user data contents
     */
    getConfig(s3Event: S3EventRecord): Promise<LambdaConfig | void>;
    private setTriggerFile;
    private checkEmail;
    private checkTriggerFile;
    /**
     * Get the latest EC2 AMI
     *
     * @param config The nshmp trigger config
     */
    private setImageId;
    /**
     * Get IAM instance profile for ec2.
     *
     * @param config The nshmp trigger config
     */
    private setIamRole;
    /**
     * Read in the user data script.
     *
     * @param config The trigger config
     */
    private setUserData;
    private setSNSSubscriberTopic;
    private getSNSSubscriber;
    private getSNSSubscriptions;
    private snsSubscribe;
}
