"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const dateFormat = require("dateformat");
/**
 * Lambda utilities
 */
class NshmpLambdaUtil {
    constructor() { }
    /**
     * Send error message notification.
     *
     * @param config The config
     * @param errorMessage The error message to send
     */
    static onError(lambdaError) {
        const config = lambdaError.lambdaConfig;
        console.error(lambdaError);
        let message = `
      AWS Lambda nshmp-haz error.
      ${dateFormat(new Date(), NshmpLambdaUtil.timeFormat)}

      ----------
      Error:

      ${lambdaError.message}

      ----------
      Trigger config file (${config.triggerFileName}):
      \n${config.rawTriggerConfig}

    `;
        const subject = `AWS nshmp-haz (job id: ${config.jobId})`;
        return NshmpLambdaUtil.sendNotification(subject, message, config);
    }
    static sendNotification(subject, message, config) {
        const sns = new AWS.SNS();
        if (config.nshmp.snsTopic.TopicArn === null) {
            return Promise.reject();
        }
        const topicArn = config.nshmp.snsTopic.TopicArn;
        return sns.publish({
            TopicArn: topicArn,
            Message: message,
            Subject: subject
        }).promise()
            .catch((error) => {
            const errorMessage = `
        Could not send notification.
        Error: ${error.message}.
        Topic Arn: ${topicArn},
        Subject: ${subject}.
        Message: ${message}.
      `;
            console.error(errorMessage);
        });
    }
}
NshmpLambdaUtil.timeFormat = 'dddd, mmmm dS, yyyy, h:MM:ss TT Z';
exports.NshmpLambdaUtil = NshmpLambdaUtil;
class LambdaError extends Error {
    constructor(message, lambdaConfig) {
        super(message);
        this.lambdaConfig = lambdaConfig;
    }
}
exports.LambdaError = LambdaError;
