"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const nshmp_haz_s3_lambda_1 = require("./lambda/nshmp-haz-s3-lambda");
const nshmp_haz_lambda_config_1 = require("./config/nshmp-haz-lambda-config");
const nshmp_lambda_util_1 = require("./lambda/nshmp-lambda-util");
/* Lock to us-west-2 */
AWS.config.region = 'us-west-2';
/* Lock the known API versions to avoid future problems */
AWS.config.apiVersions = {
    ec2: '2016-11-15',
    s3: '2016-03-01'
};
/**
 * Lambda handler
 */
exports.handler = async (event, context) => {
    console.log('\nLambda event:', JSON.stringify(event, null, 2));
    console.log('\nLambda context:', JSON.stringify(context, null, 2));
    /* Shorten id */
    const jobId = context.awsRequestId.split('-')[0];
    const lambda = new nshmp_haz_s3_lambda_1.NshmpHazS3Lambda();
    const nshmpLambdaConfig = new nshmp_haz_lambda_config_1.NshmpHazLambdaConfig(jobId);
    return await nshmpLambdaConfig.getConfig(event.Records[0])
        .then((config) => {
        return lambda.startComputeJob(config);
    })
        .then(() => 'Running nshmp-haz')
        .catch(async (error) => {
        return await nshmp_lambda_util_1.NshmpLambdaUtil.onError(error)
            .then(() => `Error [${error.message}]`)
            .catch(() => console.error(error));
    });
};
